@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: audio_alsa.c,v 1.5 2004/01/23 09:41:31 rob Exp $
+ * $Id: audio_alsa.c,v 1.6 2004/02/23 21:35:23 rob Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,7 +27,11 @@
 #include "global.h"
 
 #include <errno.h>
-#include <sys/asoundlib.h>
+
+#define ALSA_PCM_OLD_HW_PARAMS_API
+#define ALSA_PCM_OLD_SW_PARAMS_API
+#include <alsa/asoundlib.h>
+
 #include <mad.h>
 
 #include "audio.h"
