@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: madplay.c,v 1.85 2004/02/17 02:26:43 rob Exp $
+ * $Id: madplay.c,v 1.86 2004/02/23 21:34:53 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -569,7 +569,7 @@ void get_options(int argc, char *argv[], struct player *player)
 # endif
 
     case 'G':
-      player->output.replay_gain |= RGAIN_ENABLED;
+      player->output.replay_gain |= PLAYER_RGAIN_ENABLED;
 
       if (optarg) {
 	size_t len;
@@ -577,7 +577,7 @@ void get_options(int argc, char *argv[], struct player *player)
 	len = strlen(optarg);
 
 	if (len && strncmp(optarg, "audiophile", len) == 0)
-	  player->output.replay_gain |= RGAIN_AUDIOPHILE;
+	  player->output.replay_gain |= PLAYER_RGAIN_AUDIOPHILE;
 	else if (len && strncmp(optarg, "radio", len) == 0)
 	  ;
 	else
@@ -780,7 +780,7 @@ int main(int argc, char *argv[])
       warn(_("cross-fade ignored without negative gap"));
   }
 
-  if (player.output.replay_gain & RGAIN_ENABLED) {
+  if (player.output.replay_gain & PLAYER_RGAIN_ENABLED) {
     if (player.options & PLAYER_OPTION_IGNOREVOLADJ)
       warn(_("volume adjustment ignored with Replay Gain enabled"));
     else
