@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: player.c,v 1.68 2004/02/17 02:26:43 rob Exp $
+ * $Id: player.c,v 1.69 2004/02/23 21:34:53 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -85,6 +85,7 @@
 # include "resample.h"
 # include "filter.h"
 # include "tag.h"
+# include "rgain.h"
 
 # define MPEG_BUFSZ	40000	/* 2.5 s at 128 kbps; 1 s at 320 kbps */
 # define FREQ_TOLERANCE	2	/* percent sampling frequency tolerance */
@@ -705,41 +706,31 @@ void show_id3(struct id3_tag const *tag)
  * DESCRIPTION:	display Replay Gain information
  */
 static
-void show_rgain(struct tag_rgain const *rgain)
+void show_rgain(struct rgain const *rgain)
 {
-  char const *name, *originator;
+  char const *label, *source;
 
-  name = 0;
+  if (!RGAIN_VALID(rgain))
+    return;
+
+  label = 0;
   switch (rgain->name) {
-  case TAG_RGAIN_NAME_NOT_SET:
+  case RGAIN_NAME_NOT_SET:
     break;
-  case TAG_RGAIN_NAME_RADIO:
-    name = _("Radio Gain");
+  case RGAIN_NAME_RADIO:
+    label = _("Radio Gain");
     break;
-  case TAG_RGAIN_NAME_AUDIOPHILE:
-    name = _("Audiophile Gain");
-    break;
-  }
-  if (name == 0)
-    return;
-
-  originator = 0;
-  switch (rgain->originator) {
-  case TAG_RGAIN_ORIGINATOR_UNSPECIFIED:
-    return;
-  case TAG_RGAIN_ORIGINATOR_PRESET:
-    originator = _("preset");
-    break;
-  case TAG_RGAIN_ORIGINATOR_USER:
-    originator = _("user");
-    break;
-  case TAG_RGAIN_ORIGINATOR_AUTOMATIC:
-    originator = _("automatic");
+  case RGAIN_NAME_AUDIOPHILE:
+    label = _("Audiophile Gain");
     break;
   }
 
-  detail(name, originator ? "%+.1f dB (%s)" : "%+.1f dB",
-	 rgain->adjustment / 10.0, originator);
+  source = rgain_originator(rgain);
+
+  assert(label && source);
+
+  detail(label, "%+.1f dB => %d dB SPL (%s)",
+	 RGAIN_DB(rgain), (int) RGAIN_REFERENCE, source);
 }
 
 /*
@@ -1012,9 +1003,9 @@ void show_tag(struct tag const *tag)
 	     peak, 20 * log10(peak));
     }
 
-    if (tag->lame.replay_gain[0].name == TAG_RGAIN_NAME_RADIO)
+    if (tag->lame.replay_gain[0].name == RGAIN_NAME_RADIO)
       show_rgain(&tag->lame.replay_gain[0]);
-    if (tag->lame.replay_gain[1].name == TAG_RGAIN_NAME_AUDIOPHILE)
+    if (tag->lame.replay_gain[1].name == RGAIN_NAME_AUDIOPHILE)
       show_rgain(&tag->lame.replay_gain[1]);
 
     detail(_("Music Length"), _("%lu bytes"), tag->lame.music_length);
@@ -1080,48 +1071,33 @@ double set_gain(struct player *player, int how, double db)
  * DESCRIPTION:	select and employ a Replay Gain volume adjustment
  */
 static
-void use_rgain(struct player *player, struct tag_rgain *list)
+void use_rgain(struct player *player, struct rgain *list)
 {
-  struct tag_rgain *rgain = &list[0];
+  struct rgain *rgain = &list[0];
 
-  if ((player->output.replay_gain & RGAIN_AUDIOPHILE) &&
-      list[1].name == TAG_RGAIN_NAME_AUDIOPHILE &&
-      list[1].originator != TAG_RGAIN_ORIGINATOR_UNSPECIFIED)
+  if ((player->output.replay_gain & PLAYER_RGAIN_AUDIOPHILE) &&
+      list[1].name == RGAIN_NAME_AUDIOPHILE &&
+      list[1].originator != RGAIN_ORIGINATOR_UNSPECIFIED)
     rgain = &list[1];
 
-  if ((rgain->name == TAG_RGAIN_NAME_RADIO ||
-       rgain->name == TAG_RGAIN_NAME_AUDIOPHILE) &&
-      rgain->originator != TAG_RGAIN_ORIGINATOR_UNSPECIFIED) {
-    double gain = (double) rgain->adjustment / 10;
+  if (RGAIN_VALID(rgain)) {
+    double gain = RGAIN_DB(rgain);
 
     set_gain(player, GAIN_VOLADJ, gain);
 
     if (player->verbosity >= 0 ||
 	(player->options & PLAYER_OPTION_SHOWTAGSONLY)) {
-      char const *originator;
+      char const *source;
 
-      originator = 0;
-      switch (rgain->originator) {
-      case TAG_RGAIN_ORIGINATOR_UNSPECIFIED:
-	break;
-      case TAG_RGAIN_ORIGINATOR_PRESET:
-	originator = _("preset");
-	break;
-      case TAG_RGAIN_ORIGINATOR_USER:
-	originator = _("user");
-	break;
-      case TAG_RGAIN_ORIGINATOR_AUTOMATIC:
-	originator = _("automatic");
-	break;
-      }
+      source = rgain_originator(rgain);
+      assert(source);
 
       detail(_("Replay Gain"), _("%+.1f dB %s adjustment (%s)"),
-	     gain, (rgain->name == TAG_RGAIN_NAME_RADIO) ?
-	     _("radio") : _("audiophile"),
-	     originator ? originator : _("other"));
+	     gain, (rgain->name == RGAIN_NAME_RADIO) ?
+	     _("radio") : _("audiophile"), source);
     }
 
-    player->output.replay_gain |= RGAIN_SET;
+    player->output.replay_gain |= PLAYER_RGAIN_SET;
   }
 }
 
@@ -1156,8 +1132,8 @@ enum mad_flow decode_filter(void *data, struct mad_stream const *stream,
       }
       else {
 	if ((tag->flags & TAG_LAME) &&
-	    (player->output.replay_gain & RGAIN_ENABLED) &&
-	    !(player->output.replay_gain & RGAIN_SET))
+	    (player->output.replay_gain & PLAYER_RGAIN_ENABLED) &&
+	    !(player->output.replay_gain & PLAYER_RGAIN_SET))
 	  use_rgain(player, tag->lame.replay_gain);
       }
 
@@ -1332,8 +1308,8 @@ void process_id3(struct id3_tag const *tag, struct player *player)
   /* Replay Gain */
 
   if ((player->options & PLAYER_OPTION_SHOWTAGSONLY) ||
-      ((player->output.replay_gain & RGAIN_ENABLED) &&
-       !(player->output.replay_gain & RGAIN_SET))) {
+      ((player->output.replay_gain & PLAYER_RGAIN_ENABLED) &&
+       !(player->output.replay_gain & PLAYER_RGAIN_SET))) {
     frame = id3_tag_findframe(tag, "RGAD", 0);
     if (frame) {
       id3_byte_t const *data;
@@ -1351,14 +1327,14 @@ void process_id3(struct id3_tag const *tag, struct player *player)
       if (length >= 8) {
 	struct mad_bitptr ptr;
 	mad_fixed_t peak;
-	struct tag_rgain rgain[2];
+	struct rgain rgain[2];
 
 	mad_bit_init(&ptr, data);
 
 	peak = mad_bit_read(&ptr, 32) << 5;
 
-	tag_parse_rgain(&rgain[0], &ptr);
-	tag_parse_rgain(&rgain[1], &ptr);
+	rgain_parse(&rgain[0], &ptr);
+	rgain_parse(&rgain[1], &ptr);
 
 	use_rgain(player, rgain);
 
@@ -1951,7 +1927,7 @@ int play_one(struct player *player)
   if (!(player->options & PLAYER_OPTION_IGNOREVOLADJ))
     set_gain(player, GAIN_VOLADJ, 0);
 
-  player->output.replay_gain &= ~RGAIN_SET;
+  player->output.replay_gain &= ~PLAYER_RGAIN_SET;
 
   /* try reading ID3 tag information now (else read later from stream) */
   {
