@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: player.h,v 1.23 2004/02/17 02:26:43 rob Exp $
+ * $Id: player.h,v 1.24 2004/02/23 21:34:53 rob Exp $
  */
 
 # ifndef PLAYER_H
@@ -82,10 +82,10 @@ enum {
 };
 
 enum {
-  RGAIN_ENABLED    = 0x0001,
-  RGAIN_SET        = 0x0002,
-  RGAIN_AUDIOPHILE = 0x0010,
-  RGAIN_HARDLIMIT  = 0x0020
+  PLAYER_RGAIN_ENABLED    = 0x0001,
+  PLAYER_RGAIN_SET        = 0x0002,
+  PLAYER_RGAIN_AUDIOPHILE = 0x0010,
+  PLAYER_RGAIN_HARDLIMIT  = 0x0020
 };
 
 struct player {
